# seven_cloudapp_ppmt

## 天志互联Python淘宝云应用框架库(潮玩盲盒)

### 1.0.32.9 更新内容
* 新版本

### 1.0.19 更新内容
* 修改抽奖报错


### 1.0.18 更新内容
* 去掉monitor监控
* UserListHandler改成全部字段输出

### 1.0.16 更新内容
* 购买订单并发优化

### 1.0.15 更新内容
* 增加分享新用户上报

### 1.0.13 更新内容
* 潮玩盲盒v2.0整合

### 1.0.2 更新内容
* 框架内容添加
